### Description
Library for communicating with DMS-Ziva based devices

### Build and upload package
`python setup.py upload`

### Tests
Run all tests:  
`python -m unittest`

Or run only specific test:  
`python -m unittest tests.test_ziva`
